@@ -1,8 +1,10 @@
 # -*- coding: utf-8 -*-
+from __future__ import division
 from brightway2 import config, databases, methods, Database, Method, \
     JsonWrapper, reset_meta
 from bw2analyzer import ContributionAnalysis, DatabaseExplorer
 from bw2calc import LCA, ParallelMonteCarlo
+from bw2calc.speed_test import SpeedTest
 from bw2data.io import EcospoldImporter, EcospoldImpactAssessmentImporter
 from flask import Flask, url_for, render_template, request, redirect, abort
 from fuzzywuzzy import process
@@ -211,12 +213,24 @@ def change_settings():
         context = {
             "config": config,
             "cpu_count": multiprocessing.cpu_count(),
-            "current_cpu_count": config.p.get("cpu_count",
-                multiprocessing.cpu_count()),
         }
         return render_template("settings.html", **context)
     else:
-        return ""
+        config.p["use_cache"] = bool(request.form.get("use-cache", False))
+        config.p["temp_dir_ok"] = bool(request.form.get("use-temp-dir", False))
+        config.p["cpu_cores"] = int(request.form["cpu-cores"])
+        config.p["iterations"] = int(request.form["iterations"])
+        config.p["upload_reports"] = bool(request.form.get(
+            "upload-reports", False))
+        config.p["report_server_url"] = request.form["report-server"]
+        config.save_preferences()
+        return redirect(url_for('index'))
+
+
+@app.route('/speedtest')
+def speed_test():
+    st = SpeedTest()
+    return str(250 * int(40 * st.ratio()))
 
 ###########
 ### LCA ###
